summaryrefslogtreecommitdiff
path: root/include/dlt/dlt_user.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dlt/dlt_user.h')
-rw-r--r--include/dlt/dlt_user.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/dlt/dlt_user.h b/include/dlt/dlt_user.h
index 7774f83..0804f7e 100644
--- a/include/dlt/dlt_user.h
+++ b/include/dlt/dlt_user.h
@@ -514,11 +514,11 @@ DltReturnValue dlt_check_library_version(const char *user_major_version, const c
/**
* Register an application in the daemon.
* @param appid four byte long character array with the application id
* @param description long name of the application
* @return Value from DltReturnValue enum
*/
-DltReturnValue dlt_register_app(const char *appid, const char *description);
+DltReturnValue dlt_register_app(const char *apid, const char *description);
/**
* Unregister an application in the daemon.
@@ -514,11 +514,11 @@ DltReturnValue dlt_check_library_version(const char *user_major_version, const c
/**
* Register an application in the daemon.
- * @param appid four byte long character array with the application id
+ * @param apid four byte long character array with the application id
* @param description long name of the application
* @return Value from DltReturnValue enum